@@ -1,7 +1,7 @@
 # # # # # # # # # # # # # #
 # CAPTAINHOOK IDENTIFIER  #
 # # # # # # # # # # # # # #
-from .utils import bash, get_files_for_commit
+from .utils import bash
 
 DEFAULT = 'off'
 NO_ARG_MESSAGE = 'You must specify an argument to the grep checker.'
@@ -11,8 +11,8 @@ def grep(args, files):
     return bash('grep -n -H --exclude=tox.ini {} {}'.format(args, files))
 
 
-def run(arg=None):
+def run(files, arg=None):
     if arg is None:
         return NO_ARG_MESSAGE
-    files = ' '.join(get_files_for_commit())
+    files = ' '.join(files)
     return grep(arg, files).value()
