@@ -4,7 +4,7 @@
 import argparse
 
 from .grep import grep
-from .utils import python_files_for_commit
+from .utils import filter_python_files
 
 DEFAULT = 'on'
 CHECK_NAME = 'pdb'
@@ -12,12 +12,12 @@ CHECK_NAME = 'pdb'
 forbidden = '^[^#"]*pdb.set_trace()'
 
 
-def run(arg=''):
+def run(files, arg=''):
     "Look for pdb.set_trace() commands in python files."
     parser = get_parser()
     args = parser.parse_args(arg.split())
 
-    py_files = python_files_for_commit()
+    py_files = filter_python_files(files)
     if args.ignore:
         py_files = set(py_files) - set(args.ignore)
     return check_files(py_files).value()
