@@ -34,7 +34,7 @@ path = os.path.dirname(os.path.abspath(__file__))
 sys.path.append(path)
 
 import checkers
-from checkers.utils import bash, get_files_for_commit, HookConfig
+from checkers.utils import get_files, HookConfig
 
 
 def checks():
@@ -62,13 +62,8 @@ def title_print(msg):
     print(bar)
 
 
-def changes_to_stash():
-    "Check there are changes to stash"
-    return bool(bash('git diff'))
-
-
 @contextmanager
-def gitstash():
+def files_to_check(commit_only):
     """
     Validate the commit diff.
 
@@ -78,15 +73,15 @@ def gitstash():
     safe_directory = tempfile.mkdtemp()
     TEMP_FOLDER = safe_directory
 
-    get_files_for_commit(copy_dest=safe_directory)
+    files = get_files(commit_only=commit_only, copy_dest=safe_directory)
 
     try:
-        yield
+        yield files
     finally:
         shutil.rmtree(safe_directory)
 
 
-def main():
+def main(commit_only=True):
     """
     Run the configured code checks.
 
@@ -97,18 +92,18 @@ def main():
     global TEMP_FOLDER
     exit_code = 0
     hook_checks = HookConfig('tox.ini')
-    with gitstash():
+    with files_to_check(commit_only) as files:
         for name, mod in checks():
             default = getattr(mod, 'DEFAULT', 'off')
             if hook_checks.is_enabled(name, default=default):
                 args = hook_checks.arguments(name)
                 if args:
-                    errors = mod.run(args)
+                    errors = mod.run(files, args)
                 else:
-                    errors = mod.run()
+                    errors = mod.run(files)
                 if errors:
                     title_print("Checking {0}".format(name))
-                    print(errors.replace(TEMP_FOLDER + "/", ''))
+                    print((errors.replace(TEMP_FOLDER + "/", '')))
                     exit_code = 1
 
     if exit_code == 1:
@@ -120,6 +115,9 @@ if __name__ == '__main__':
     import argparse
 
     parser = argparse.ArgumentParser()
+    parser.add_argument('--all', action='store_true',
+                        help=('Run the checks against the whole code base')
+                        )
     args = parser.parse_args()
-    exit_code = main()
+    exit_code = main(commit_only=not args.all)
     sys.exit(exit_code)
